require 'test_helper'
require 'work_in_progress'

class ViewHelpersTest < Minitest::Test
  def setup
    @object = Object.new
    @object.extend(WorkInProgress::ViewHelpers)
  end

  def content
    "<div style=\"background-color: #ccc;\">hello!</div>"
  end

  User = Struct.new(:email)

  # Test Rails
  def test_rails_for_all
    WorkInProgress.setup do |config|
      config.framework = :rails
    end

    assert_nil(@object.work_in_progress { "hello!" })
  end

  def test_rails_for_unpermitted_users
    WorkInProgress.setup do |config|
      config.framework = :rails
      config.permited_users = ["permited@example.com"]
    end

    user = User.new("notpermited@example.com")
    assert_nil(@object.work_in_progress(user: user) { "hello!" })
  end

  def test_rails_for_permitted_users
    WorkInProgress.setup do |config|
      config.framework = :rails
      config.permited_users = ["permited@example.com"]
    end

    user = User.new("permited@example.com")
    assert_equal(content, @object.work_in_progress(user: user) { "hello!" })
  end

  # Test other frameworks
  def test_sinatra
    WorkInProgress.setup do |config|
      config.framework = :sinatra
    end

    assert_nil(@object.work_in_progress { "hello!" })
  end
end